Crossbar.io
===========

| |Version| |Downloads| |Build Status| |Coverage|

--------------

`Crossbar.io <http://crossbar.io>`__ is an open-source `WAMP <http://wamp.ws/>`__ application router that allows to build advanced applications from loosely-coupled components that can talk in real-time with each other.

-  Read more on the `Crossbar.io project homepage <http://crossbar.io>`__
-  Jump into the `Quick Start <http://crossbar.io/docs/Quick-Start/>`__
-  Checkout the complete `Documentation <http://crossbar.io/docs/>`__
-  Join the `Mailing List <https://groups.google.com/forum/#!forum/crossbario>`__
-  Follow us on `Twitter <https://twitter.com/crossbario>`__
-  Ask a question on `StackOverflow <http://stackoverflow.com/questions/ask?tags=crossbar,wamp>`__
-  Read our `Legal Notes <legal/README.md>`__

.. |Version| image:: https://img.shields.io/pypi/v/crossbar.svg
   :target: https://pypi.python.org/pypi/crossbar
.. |Downloads| image:: https://img.shields.io/pypi/dm/crossbar.svg
   :target: https://pypi.python.org/pypi/crossbar
.. |Build Status| image:: https://travis-ci.org/crossbario/crossbar.svg?branch=master
   :target: https://travis-ci.org/crossbario/crossbar
.. |Coverage| image:: https://img.shields.io/codecov/c/github/crossbario/crossbar/master.svg
   :target: https://codecov.io/github/crossbario/crossbar
